import cloudfront = require('@aws-cdk/aws-cloudfront');
import s3 = require('@aws-cdk/aws-s3');
import cdk = require('@aws-cdk/core');
import { Construct } from '@aws-cdk/core';
export interface StaticSiteProps {
    readonly domainName: string;
    readonly siteSubDomain: string;
    /**
     * Serve parking page in place of static page
     *
     * @default boolean false
     */
    readonly serveParkingPage?: boolean;
    /**
     * Provide a bucket for the static pages, if none is provided a default bucket is created
     */
    readonly staticSiteBucket?: s3.Bucket;
    /**
     * Bucket removal policy for default bucket
     * @default cdk.RemovalPolicy cdk.RemovalPolicy.RETAIN
     */
    readonly staticSiteBucketRemovalPolicy?: cdk.RemovalPolicy;
}
/**
 * Static site infrastructure, which deploys site content to an S3 bucket.
 *
 * The site redirects from HTTP to HTTPS, using a CloudFront distribution,
 * Route53 alias record, and ACM certificate.
 */
export declare class CdkStaticSite extends cdk.Construct {
    /** @returns the s3 bucket where the site files are located */
    readonly bucket: s3.Bucket;
    readonly cloudfrontDistribution: cloudfront.CloudFrontWebDistribution;
    constructor(parent: Construct, name: string, props: StaticSiteProps);
}
